@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '1.55'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 # Platypus-Man,
 # Platypus-Man,
@@ -593,7 +593,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 1.55
+version 1.57
 
 =head1 SYNOPSIS
 
@@ -618,8 +618,8 @@ L<Go|FFI::Platypus::Lang::Go>,
 L<Fortran|FFI::Platypus::Lang::Fortran>,
 L<Rust|FFI::Platypus::Lang::Rust>,
 L<Pascal|FFI::Platypus::Lang::Pascal>. Essentially anything that gets
-compiled into machine code.  This implementation uses C<libffi> to
-accomplish this task.  C<libffi> is battle tested by a number of other
+compiled into machine code.  This implementation uses L<libffi|https://sourceware.org/libffi/> to
+accomplish this task.  L<libffi|https://sourceware.org/libffi/> is battle tested by a number of other
 scripting and virtual machine languages, such as Python and Ruby to
 serve a similar role.  There are a number of reasons why you might want
 to write an extension with Platypus instead of XS:
@@ -2354,12 +2354,10 @@ the development package for C<libffi> as prereqs for this module.
 
 =head1 SEE ALSO
 
+=head2 Extending Platypus
+
 =over 4
 
-=item L<NativeCall>
-
-Promising interface to Platypus inspired by Raku.
-
 =item L<FFI::Platypus::Type>
 
 Type definitions for Platypus.
@@ -2385,13 +2383,15 @@ The custom types API for Platypus.
 
 Memory functions for FFI.
 
-=item L<FFI::CheckLib>
+=back
 
-Find dynamic libraries in a portable way.
+=head2 Languages
+
+=over 4
 
 =item L<FFI::TinyCC>
 
-JIT compiler for FFI.
+JIT C compiler for FFI.
 
 =item L<FFI::Platypus::Lang::C>
 
@@ -2434,6 +2434,16 @@ Modules for writing WebAssembly bindings in Perl.  This allows you to call
 functions written in any language supported by WebAssembly.  These modules
 are also implemented using Platypus.
 
+=back
+
+=head2 Other Tools Related Tools Useful for FFI
+
+=over 4
+
+=item L<FFI::CheckLib>
+
+Find dynamic libraries in a portable way.
+
 =item L<Convert::Binary::C>
 
 A great interface for decoding C data structures, including C<struct>s,
@@ -2449,6 +2459,21 @@ This module can extract constants and other useful objects from C header
 files that may be relevant to an FFI application.  One downside is that
 its use may require development packages to be installed.
 
+=back
+
+=head2 Other Foreign Function Interfaces
+
+=over 4
+
+=item L<Dyn>
+
+A wrapper around L<dyncall|https://dyncall.org>, which is itself an alternative to
+L<libffi|https://sourceware.org/libffi/>.
+
+=item L<NativeCall>
+
+Promising interface to Platypus inspired by Raku.
+
 =item L<Win32::API>
 
 Microsoft Windows specific FFI style interface.
@@ -2473,10 +2498,6 @@ Another FFI for Perl that doesn't appear to have worked for a long time.
 
 Embed a tiny C compiler into your Perl scripts.
 
-=item L<Alien::FFI>
-
-Provides libffi for Platypus during its configuration and build stages.
-
 =item L<P5NCI>
 
 Yet another FFI like interface that does not appear to be supported or
@@ -2484,6 +2505,16 @@ under development anymore.
 
 =back
 
+=head2 Other
+
+=over 4
+
+=item L<Alien::FFI>
+
+Provides libffi for Platypus during its configuration and build stages.
+
+=back
+
 =head1 ACKNOWLEDGMENTS
 
 In addition to the contributors mentioned below, I would like to
@@ -2544,7 +2575,7 @@ Pete Houston (openstrike, HOUSTON)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
+This software is copyright (c) 2015-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
